==> haskell-typst-0.5.0.2-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.5.0.2
visibility:           public
id:                   typst-0.5.0.2-F9KeUL8iDn3ARqEAXKcgy8
key:                  typst-0.5.0.2-F9KeUL8iDn3ARqEAXKcgy8
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.10
    and currently offers only partial support.

category:             Text
abi:                  c8ddc4d0220960b3a0434bd59cfe7211
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Typst.Bind Typst.Regex Typst.Show Typst.Module.Standard
    Typst.Module.Math Typst.Module.Calc Typst.MathClass

import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.5.0.2-F9KeUL8iDn3ARqEAXKcgy8
depends:
    aeson-2.1.2.1-LRjlcarryWV47QfBrWIlNe array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.3.2-3cmMkmT3ry2LkQafUKMmqG
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    ordered-containers-0.2.4-I0UYF9OkcxB2vBPDG97rUG parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.4-EbLRF4X8gSY41Kv2woMc7r
    scientific-0.3.7.0-EaRpQXcrvKCD1LBpAEBJcM text-2.0.2 time-1.12.2
    toml-parser-2.0.1.1-2qndTLP3Ca4DmQYks4d4JI
    typst-symbols-0.1.5-CKv9nghfbzV9YElGsqLgYY
    vector-0.13.2.0-F8322NeNtfL69paM3N9AVt
    xml-conduit-1.9.1.4-GVr562sMXWT20JDX9qu5ou
    yaml-0.11.11.2-EmOeXA0EbKy7yEQwIKCezQ

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-typst-0.5.0.2-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-typst.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 typst
version:              0.5.0.2
visibility:           public
id:                   typst-0.5.0.2-IUrzfj7thk934qe1v1rIGh
key:                  typst-0.5.0.2-IUrzfj7thk934qe1v1rIGh
license:              BSD-3-Clause
copyright:            Copyright 2023 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Parsing and evaluating typst syntax.
description:
    A library for parsing and evaluating typst syntax.
    Typst (<https://typst.app>) is a document layout and
    formatting language. This library targets typst 0.10
    and currently offers only partial support.

category:             Text
abi:                  20c49a50e8c01489409a1522f820ca31
exposed:              True
exposed-modules:
    Typst Typst.Evaluate Typst.Methods Typst.Parse Typst.Syntax
    Typst.Types Typst.Util

hidden-modules:
    Typst.Bind Typst.Regex Typst.Show Typst.Module.Standard
    Typst.Module.Math Typst.Module.Calc Typst.MathClass

import-dirs:          /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/typst-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-typst
hs-libraries:         HStypst-0.5.0.2-IUrzfj7thk934qe1v1rIGh
depends:
    aeson-2.1.2.1-EZ4q40CmD1e6rYIqwxbubT array-0.5.4.0 base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.3.2-7HUSeILq3wZBq3hhOarIKV
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2 mtl-2.2.2
    ordered-containers-0.2.4-I0UYF9OkcxB2vBPDG97rUG parsec-3.1.16.1
    pretty-1.1.3.6 regex-tdfa-1.3.2.4-ItsMnXJxK6WYN4XUqMa9n
    scientific-0.3.7.0-EaRpQXcrvKCD1LBpAEBJcM text-2.0.2 time-1.12.2
    toml-parser-2.0.1.1-6PAKLU9gqud2HCK6X3OuUH
    typst-symbols-0.1.5-CKv9nghfbzV9YElGsqLgYY
    vector-0.13.2.0-F8322NeNtfL69paM3N9AVt
    xml-conduit-1.9.1.4-AaBzSbnM0I14SQSwzLMEhM
    yaml-0.11.11.2-AbuBy3Luu5i9H58LcRMnvm

haddock-interfaces:   /usr/share/doc/haskell-typst/html/typst.haddock
haddock-html:         /usr/share/doc/haskell-typst/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
